@@ -7,6 +7,7 @@ mod use_is_mounted;
 mod use_latest;
 mod use_local_storage;
 mod use_mount;
+mod use_previous;
 mod use_session_storage;
 mod use_timeout;
 mod use_title;
@@ -23,6 +24,7 @@ pub use use_is_mounted::*;
 pub use use_latest::*;
 pub use use_local_storage::*;
 pub use use_mount::*;
+pub use use_previous::*;
 pub use use_session_storage::*;
 pub use use_timeout::*;
 pub use use_title::*;
