@@ -1,5 +1,8 @@
 use gloo::timers::callback::Interval;
-use yew::{use_effect_with_deps, use_mut_ref};
+
+use yew::prelude::*;
+
+use super::use_mut_latest;
 
 /// A hook that schedules an interval to invoke `callback` every `millis` milliseconds.
 /// The interval will be cancelled if `millis` is set to 0.
@@ -33,26 +36,16 @@ pub fn use_interval<Callback>(callback: Callback, millis: u32)
 where
     Callback: FnMut() + 'static,
 {
-    let callback_ref = use_mut_ref(|| None);
+    let callback_ref = use_mut_latest(callback);
     let interval_ref = use_mut_ref(|| None);
 
-    // Update the ref each render so if it changes the newest callback will be invoked.
-    *callback_ref.borrow_mut() = Some(callback);
-
     use_effect_with_deps(
         move |millis| {
             if *millis > 0 {
                 *interval_ref.borrow_mut() = Some(Interval::new(*millis, move || {
-                    let callback = (*callback_ref.borrow_mut()).take();
-
-                    if let Some(mut callback) = callback {
-                        callback();
-
-                        // Put back callback if needed.
-                        if (*callback_ref.borrow_mut()).is_none() {
-                            *callback_ref.borrow_mut() = Some(callback);
-                        }
-                    }
+                    let callback_ref = callback_ref.current();
+                    let callback = &mut *callback_ref.borrow_mut();
+                    callback();
                 }));
             } else {
                 *interval_ref.borrow_mut() = None;
